@@ -3,6 +3,7 @@ import os.path
 from .base_producer import BlockingProducer
 from ..models import ArtifactUploadRequest, ArtifactMetadata, ArtifactBuildMetadata
 from ..models import QueueMessage
+from . import create_span_decorator
 from socket import gethostname
 from datetime import datetime
 import base64
@@ -15,6 +16,8 @@ __all__ = [
     "LocalUbaiArtifactUploadRequestProducer",
 ]
 
+span_decorator = create_span_decorator()
+
 MESSAGE_QUEUE_SIZE_LIMIT = 67108864  # 64MB
 
 class UbaiArtifactUploadRequestProducer:
@@ -24,6 +27,7 @@ class UbaiArtifactUploadRequestProducer:
         self.__client.queue_declare(queue=self.queue_name, durable=True)
         self.producer_app_id = producer_app_id
 
+    @span_decorator
     def upload_artifact(
         self, artifact_file: str, metadata: dict, validate_metadata: bool=True
     ):
@@ -63,6 +67,7 @@ class UbaiArtifactUploadRequestProducer:
             )
             self.publish_artifact_upload_request(artifact_request)
 
+    @span_decorator
     def publish_artifact_upload_request(self, artifact_request: ArtifactUploadRequest):
         queue_message = QueueMessage(
             payload=artifact_request,
